@@ -1846,7 +1846,7 @@ display_draw (GtkWidget *widget, cairo_t *cr, gpointer data)
 
 #ifdef HAVE_RSVG
 	if (eog_image_is_svg (view->priv->image)) {
-		cairo_matrix_t matrix, translate, scale;
+		cairo_matrix_t matrix, translate, scale, original;
 		EogTransform *transform = eog_image_get_transform (priv->image);
 		cairo_matrix_init_identity (&matrix);
 		if (transform) {
@@ -1883,6 +1883,8 @@ display_draw (GtkWidget *widget, cairo_t *cr, gpointer data)
 		cairo_matrix_init_translate (&translate, xofs, yofs);
 		cairo_matrix_multiply (&matrix, &matrix, &translate);
 
+		cairo_get_matrix (cr, &original);
+		cairo_matrix_multiply (&matrix, &matrix, &original);
 		cairo_set_matrix (cr, &matrix);
 
 		rsvg_handle_render_cairo (eog_image_get_svg (priv->image), cr);
